pub struct RawAdvances {
pub len: usize,
pub gids: *const u32,
pub advances: *mut i32,
pub gid_stride: isize,
pub advance_stride: isize,
}Expand description
Raw C-style view over a batch of glyphs and their writable advances.
Fields
len: usizeNumber of batch entries.
gids: *const u32Pointer to glyphs (read-only).
advances: *mut i32Pointer to horizontal advances (writable).
See “Metrics scaling” in the FontFuncs for details on what value this method should return.
gid_stride: isizeByte stride between successive glyphs.
advance_stride: isizeByte stride between successive advances.